==> zio-aws-serverlessapplicationrepository_3-5.17.130.7-sources.jar: zio/aws/serverlessapplicationrepository/model/CreateCloudFormationTemplateRequest.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class CreateCloudFormationTemplateRequest(
    applicationId: __string,
    semanticVersion: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest = {
    import CreateCloudFormationTemplateRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .optionallyWith(semanticVersion.map(value => value: java.lang.String))(
        _.semanticVersion
      )
      .build()
  }
  def asReadOnly
      : zio.aws.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest
      .wrap(buildAwsValue())
}
object CreateCloudFormationTemplateRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest =
      zio.aws.serverlessapplicationrepository.model
        .CreateCloudFormationTemplateRequest(
          applicationId,
          semanticVersion.map(value => value)
        )
    def applicationId: __string
    def semanticVersion: Option[__string]
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getSemanticVersion: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("semanticVersion", semanticVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest
  ) extends zio.aws.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val semanticVersion: Option[__string] =
      scala.Option(impl.semanticVersion()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest
  ): zio.aws.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-serverlessapplicationrepository_3-5.20.32.1-sources.jar: zio/aws/serverlessapplicationrepository/model/CreateCloudFormationTemplateRequest.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class CreateCloudFormationTemplateRequest(
    applicationId: __string,
    semanticVersion: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest = {
    import CreateCloudFormationTemplateRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .optionallyWith(semanticVersion.map(value => value: java.lang.String))(
        _.semanticVersion
      )
      .build()
  }
  def asReadOnly
      : zio.aws.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest
      .wrap(buildAwsValue())
}
object CreateCloudFormationTemplateRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest =
      zio.aws.serverlessapplicationrepository.model
        .CreateCloudFormationTemplateRequest(
          applicationId,
          semanticVersion.map(value => value)
        )
    def applicationId: __string
    def semanticVersion: Optional[__string]
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getSemanticVersion: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("semanticVersion", semanticVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest
  ) extends zio.aws.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val semanticVersion: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.semanticVersion())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest
  ): zio.aws.serverlessapplicationrepository.model.CreateCloudFormationTemplateRequest.ReadOnly =
    new Wrapper(impl)
}
